@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007 by Canonical Ltd
+# Copyright (C) 2005-2008 by Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -10,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 """Functionality for controlling a Patch Queue Manager (pqm).
 """
 
@@ -22,12 +22,12 @@ from bzrlib.option import Option
 from bzrlib.bzrdir import BzrDir
 
 
-version_info = (1, 0, 0, 'dev', 0)
+version_info = (1, 3, 0, 'final', 0)
 
 if version_info[3] == 'final':
     version_string = '%d.%d.%d' % version_info[:3]
 else:
-    version_string = '%d.%d.%d.%s.%d' % version_info
+    version_string = '%d.%d.%d%s%d' % version_info
 __version__ = version_string
 
 
@@ -84,8 +84,8 @@ class cmd_pqm_submit(Command):
 
     def run(self, location=None, message=None, public_location=None,
             dry_run=False, submit_branch=None):
+        from bzrlib import errors, trace
         if __name__ != 'bzrlib.plugins.pqm':
-            from bzrlib import trace
             trace.warning('The bzr-pqm plugin needs to be called'
                           ' "bzrlib.plugins.pqm" not "%s"\n'
                           'Please rename the plugin.',
@@ -96,13 +96,14 @@ class cmd_pqm_submit(Command):
         if location is None:
             location = '.'
         tree, b, relpath = BzrDir.open_containing_tree_or_branch(location)
-        if relpath and not tree:
-            from bzrlib import errors
-            raise errors.BzrCommandError('No working tree was found, but we'
-                                          ' were not given the exact path to'
-                                          ' the branch.\n'
-                                          ' We found the branch at: %s'
-                                          % (b.base,))
+        if relpath and not tree and location != '.':
+            raise errors.BzrCommandError(
+                'No working tree was found, but we were not given the '
+                'exact path to the branch.\n'
+                'We found a branch at: %s' % (b.base,))
+        if message is None:
+            raise errors.BzrCommandError(
+                'You must supply a commit message for the pqm to use.')
         submit(b, message=message, dry_run=dry_run,
                public_location=public_location,
                submit_location=submit_branch,
