@@ -1,4 +1,4 @@
-# Copyright (C) 2005, 2006, 2007 by Canonical Ltd
+# Copyright (C) 2005-2008 by Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -10,9 +10,9 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 """Submit an email to a Patch Queue Manager"""
 
 from bzrlib import (
@@ -37,6 +37,15 @@ class BadCommitMessage(errors.BzrError):
         self.msg = message
 
 
+class NoPQMSubmissionAddress(errors.BzrError):
+
+    _fmt = "No PQM submission email address specified for %(branch_url)s."
+
+    def __init__(self, branch):
+        branch_url = urlutils.unescape_for_display(branch.base, 'ascii')
+        errors.BzrError.__init__(self, branch_url=branch_url)
+
+
 class PQMEmailMessage(EmailMessage):
     """PQM doesn't support proper email subjects, so we hack around it."""
 
@@ -87,10 +96,7 @@ class PQMSubmission(object):
                     public_location = urlutils.join(public_repo, branch_relpath)
 
             if public_location is None:
-                raise errors.BzrCommandError(
-                    'No public branch location given.  Please specify with '
-                    '--public-location or see "bzr help pqm-submit" to see how '
-                    'to set it in ~/.bazaar/locations.conf')
+                raise errors.NoPublicBranch(self.source_branch)
         self.public_location = public_location
 
         if submit_location is None:
@@ -118,10 +124,7 @@ class PQMSubmission(object):
         self.submit_location = submit_location
 
         # Check that the message is okay to pass to PQM
-        if message is None:
-            repository = self.source_branch.repository
-            rev = repository.get_revision(self.source_branch.last_revision())
-            message = rev.message
+        assert message is not None
         self.message = message.encode('utf8')
         if '\n' in self.message:
             raise BadCommitMessage(self.message)
@@ -136,7 +139,7 @@ class PQMSubmission(object):
             basis_tree = self.tree.basis_tree()
             basis_tree.lock_read()
             try:
-                for change in self.tree._iter_changes(basis_tree):
+                for change in self.tree.iter_changes(basis_tree):
                     # If we have any changes, the tree is not clean
                     raise errors.UncommittedChanges(self.tree)
             finally:
@@ -197,8 +200,7 @@ def submit(branch, message, dry_run=False, public_location=None,
     mail_from = mail_from.encode('utf8') # Make sure this isn't unicode
     mail_to = config.get_user_option('pqm_email')
     if not mail_to:
-        raise errors.BzrCommandError('No PQM submission address specified '
-                                     'in configuration')
+        raise NoPQMSubmissionAddress(branch)
     mail_to = mail_to.encode('utf8') # same here
 
     submission.check_tree()
